``hornet``
==========

**WARNING** This library is currently under development and is not functional.

The hornet library aims to provide a relatively simple interface for working
with stacking nested configurations from multiple sources.  These sources may be
JSON files, YAML files, specially formatted environment variables, databases, or
anything else that you can dream up.

Basic Usage
===========

TODO

Features
========

TODO

Documentation
=============

TODO

Installation
============

The recommended way to install is using ``pip`` or ``conda``::

    pip install hornet
    conda install hornet

Or it can be installed from source using ``setuptools``::

    python setup.py install

Bugs and issues
===============

If you find a bug, let me know at https://github.com/bheklilr/hornet/issues.  Or
if you feel really motivated, write the fix and submit a pull request.

License
=======

I'm using MIT because that's what I'm most familiar with, but really I don't
care who uses this software or for what reason.  I make no claim to its accuracy
or reliability, use at your own risk.  This is just a side project for me, so
don't expect too much.  If you need it under a different license, just shoot me
an email and I'll work with you on how to make that happen.
